@@ -1,10 +1,6 @@
 """An HTTP Request metric"""
 
-from baretypes import (
-    Scope,
-    Info,
-    RouteMatches
-)
+from bareasgi import HttpRequest
 
 from jetblack_metrics import TimedMetric
 
@@ -16,23 +12,17 @@ class HttpRequestMetric(TimedMetric):
             self,
             host: str,
             app_name: str,
-            scope: Scope,
-            info: Info,
-            matches: RouteMatches
+            request: HttpRequest
     ) -> None:
         """Create an HTTP request metric
-        
+
         Args:
             host (str): The host
             app_name (str): The name of the application
-            scope (Scope): The ASGI scope
-            info (Info): The application defined info
-            matches (RouteMatches): The route matches
+            request (HttpRequest): The request
         """
         super().__init__()
         self.host = host
         self.app_name = app_name
-        self.scope = scope
-        self.info = info
-        self.matches = matches
+        self.request = request
         self.status = 500
