@@ -3,18 +3,17 @@
 from socket import gethostname
 from typing import Optional, Type
 
-from baretypes import (
-    Scope,
-    Info,
-    RouteMatches,
-    Content,
-    HttpRequestCallback,
-    HttpResponse
+from bareasgi import (
+    HttpRequest,
+    HttpResponse,
+    HttpRequestCallback
 )
 
-from .metrics import HttpRequestMetric, PrometheusHttpRequestMetric
 from jetblack_metrics import monitor
 
+from .metrics import HttpRequestMetric, PrometheusHttpRequestMetric
+
+
 class PrometheusMiddleware:
     """Prometheus Middleware"""
 
@@ -26,7 +25,7 @@ class PrometheusMiddleware:
             app_name: Optional[str] = None
     ):
         """Prometheus middleware
-        
+
         Args:
             metric_type (Type[HttpRequestMetric], optional): The metric type.
                 Defaults to None.
@@ -40,13 +39,14 @@ class PrometheusMiddleware:
 
     async def __call__(
             self,
-            scope: Scope,
-            info: Info,
-            matches: RouteMatches,
-            content: Content,
+            request: HttpRequest,
             handler: HttpRequestCallback
     ) -> HttpResponse:
-        with monitor(self.metric_type(self.host, self.app_name, scope, info, matches)) as metric:
-            status, headers, content, pushes = await handler(scope, info, matches, content)
-            metric.status = status
-            return status, headers, content, pushes
+        with monitor(self.metric_type(
+                self.host,
+                self.app_name,
+                request
+        )) as metric:
+            response = await handler(request)
+            metric.status = response.status
+            return response
